.. PyPot documentation master file, created by
   sphinx-quickstart on Sat Sep 15 18:52:00 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Pypot
*****

Welcome to Pypot's documentation!
=================================

**Introduction**

.. toctree::
    :titlesonly:
    :maxdepth: 2

    about.rst
    installation.rst
    quickstart.rst

.. _tutorial:

**Tutorial**

.. toctree::
    :titlesonly:
    :maxdepth: 2

    controlling_robot.rst
    primitive.rst
    logging.rst
    remote_access.rst


**Tools**

.. toctree::
    :titlesonly:
    :maxdepth: 2

    herborist.rst
    move.rst


**Misc**

.. toctree::
    :titlesonly:
    :maxdepth: 1

    api.rst
    FAQ.rst
    knownissues.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`